@@ -64,8 +64,8 @@ main (int argc, char *argv[])
 	gtk_init (&argc, &argv);
 
 	/* TRANSLATORS: program name: application to install a package to provide a file */
-	g_set_application_name (_("PackageKit File Installer"));
-	context = g_option_context_new ("gpk-install-file");
+	g_set_application_name (_("Software Install"));
+	context = g_option_context_new ("gpk-install-local-file");
 	g_option_context_set_summary (context, _("PackageKit File Installer"));
 	g_option_context_add_main_entries (context, options, NULL);
 	g_option_context_add_group (context, gpk_debug_get_option_group ());
@@ -114,7 +114,7 @@ main (int argc, char *argv[])
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (!ret && !gpk_ignore_session_error (error)) {
-		/* TRANSLATORS: This is when the specified DBus method did not execute successfully */
+		/* TRANSLATORS: This is when the specified D-Bus method did not execute successfully */
 		gpk_error_dialog (_("The action could not be completed"),
 				  /* TRANSLATORS: we don't have anything more useful to translate. sorry. */
 				  _("The request failed. More details are available in the detailed report."),
