@@ -27,11 +27,10 @@
 #include <locale.h>
 #include <dbus/dbus-glib.h>
 
-#include "egg-debug.h"
-
 #include "gpk-common.h"
 #include "gpk-error.h"
 #include "gpk-dbus.h"
+#include "gpk-debug.h"
 
 /**
  * main:
@@ -64,11 +63,11 @@ main (int argc, char *argv[])
 	gtk_init (&argc, &argv);
 
 	/* TRANSLATORS: program name: installs a package (or packages) by name */
-	g_set_application_name (_("Package Name Installer"));
+	g_set_application_name (_("Software Install"));
 	context = g_option_context_new ("gpk-install-package");
 	g_option_context_set_summary (context, _("Package Name Installer"));
 	g_option_context_add_main_entries (context, options, NULL);
-	g_option_context_add_group (context, egg_debug_get_option_group ());
+	g_option_context_add_group (context, gpk_debug_get_option_group ());
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	g_option_context_parse (context, &argc, &argv, NULL);
 	g_option_context_free (context);
@@ -89,7 +88,7 @@ main (int argc, char *argv[])
 	/* check dbus connections, exit if not valid */
 	connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 	if (connection == NULL) {
-		egg_warning ("%s", error->message);
+		g_warning ("%s", error->message);
 		goto out;
 	}
 
@@ -99,7 +98,7 @@ main (int argc, char *argv[])
 					   "/org/freedesktop/PackageKit",
 					   "org.freedesktop.PackageKit.Modify");
 	if (proxy == NULL) {
-		egg_warning ("Cannot connect to session service");
+		g_warning ("Cannot connect to session service");
 		goto out;
 	}
 
@@ -114,12 +113,12 @@ main (int argc, char *argv[])
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (!ret && !gpk_ignore_session_error (error)) {
-		/* TRANSLATORS: This is when the specified DBus method did not execute successfully */
+		/* TRANSLATORS: This is when the specified D-Bus method did not execute successfully */
 		gpk_error_dialog (_("The action could not be completed"),
 				  /* TRANSLATORS: we don't have anything more useful to translate. sorry. */
 				  _("The request failed. More details are available in the detailed report."),
 				  error->message);
-		egg_warning ("%s", error->message);
+		g_warning ("%s", error->message);
 		goto out;
 	}
 out:
