@@ -428,7 +428,7 @@ gpk_prefs_progress_cb (PkProgress *progress, PkProgressType type, GpkPrefsPrivat
 	g_object_get (progress,
 		      "status", &priv->status,
 		      NULL);
-	g_debug ("now %s", pk_status_enum_to_text (priv->status));
+	g_debug ("now %s", pk_status_enum_to_string (priv->status));
 
 	if (priv->status == PK_STATUS_ENUM_FINISHED) {
 		/* we've not yet shown, so don't bother */
@@ -503,7 +503,7 @@ gpk_prefs_repo_enable_cb (GObject *object, GAsyncResult *res, GpkPrefsPrivate *p
 	/* check error code */
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
-		g_warning ("failed to set repo: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
+		g_warning ("failed to set repo: %s, %s", pk_error_enum_to_string (pk_error_get_code (error_code)), pk_error_get_details (error_code));
 		window = GTK_WINDOW (gtk_builder_get_object (priv->builder, "dialog_prefs"));
 		/* TRANSLATORS: for one reason or another, we could not enable or disable a software source */
 		gpk_error_dialog_modal (window, _("Failed to change status"),
@@ -649,7 +649,7 @@ gpk_prefs_get_repo_list_cb (GObject *object, GAsyncResult *res, GpkPrefsPrivate
 	/* check error code */
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
-		g_warning ("failed to get repo list: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
+		g_warning ("failed to get repo list: %s, %s", pk_error_enum_to_string (pk_error_get_code (error_code)), pk_error_get_details (error_code));
 		window = GTK_WINDOW (gtk_builder_get_object (priv->builder, "dialog_prefs"));
 		/* TRANSLATORS: for one reason or another, we could not get the list of sources */
 		gpk_error_dialog_modal (window, _("Failed to get the list of sources"),
@@ -818,17 +818,6 @@ gpk_prefs_close_cb (GtkWidget *widget, gpointer data)
 	g_application_release (G_APPLICATION (priv->application));
 }
 
-/**
- * gpk_prefs_delete_event_cb:
- **/
-static gboolean
-gpk_prefs_delete_event_cb (GtkWidget *widget, GdkEvent *event, GpkPrefsPrivate *priv)
-{
-	gpk_prefs_close_cb (widget, priv);
-	return FALSE;
-}
-
-
 /**
  * gpk_pack_startup_cb:
  **/
@@ -904,8 +893,6 @@ gpk_pack_startup_cb (GtkApplication *application, GpkPrefsPrivate *priv)
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW (widget));
 
 	main_window = GTK_WIDGET (gtk_builder_get_object (priv->builder, "dialog_prefs"));
-	g_signal_connect (main_window, "delete_event",
-			  G_CALLBACK (gpk_prefs_delete_event_cb), priv);
 	gtk_application_add_window (application, GTK_WINDOW (main_window));
 
 	gtk_widget_show (main_window);
